
#include <qapplication.h>
#include <qvbox.h>
#include <qmenubar.h>
#include <qsplitter.h>
#include "Viewer2D.h"

void printUsage( char * s ) {
   fprintf( stderr, "Usage: %s [directory]\n", s );
}

int main( int argc, char ** argv ) {

   QApplication app( argc, argv );

   if ( argc > 2 ) {
      printUsage( argv[0] );
      return 1;
   }

   QVBox vbox( 0 );

   QMenuBar menubar( &vbox );

   QSplitter splitter( QSplitter::Horizontal, &vbox );

   DirectoryView dirview( &splitter );
   dirview.setApp( &app );
   dirview.addColumn( "Name" );
   dirview.addColumn( "Type" );
   dirview.addColumn( "Size" );
   dirview.setColumnAlignment( 2, Qt::AlignRight );
   dirview.setAllColumnsShowFocus( TRUE );
   dirview.setCaption( "Directory Browser" );

   QPopupMenu optionsMenu;
   menubar.insertItem( "Options", &optionsMenu );
   //menu.insertItem( "Display Icons", &dirview, SLOT(toggleIcons()) );//FIXME
   //menu.setCheckable( true ); // FIXME: need dirview to update checkbox
   optionsMenu.insertItem( "Quit", &dirview, SLOT(causeQuit()) );
   QPopupMenu subtreeMenu;
   menubar.insertItem( "Subtree", &subtreeMenu );
   subtreeMenu.insertItem(
      "Up", &dirview, SLOT(loadParentOfCurrentSubtree()),
      Qt::CTRL + Qt::Key_U
   );
   subtreeMenu.insertItem(
      "Down To Selection", &dirview, SLOT(loadSubtreeUnderCurrentItem()),
      Qt::CTRL + Qt::Key_D
   );
   QPopupMenu directoryMenu;
   menubar.insertItem( "Directory", &directoryMenu );
   directoryMenu.insertItem(
      "Compute Size of Selected",
      &dirview, SLOT(computeSizeOfCurrentDirectory()),
      Qt::CTRL + Qt::Key_S
   );

   dirview.loadSubtree( argc >= 2 ? argv[1] : "." );

   Viewer2D viewport( &splitter );
   splitter.setResizeMode( &dirview, QSplitter::KeepSize );

   QObject::connect( &dirview, SIGNAL(selectionChanged( QListViewItem * )),
      &viewport, SLOT(fileSelected( QListViewItem * ))
   );
   QObject::connect( &dirview, SIGNAL(contentsCleared()),
      &viewport, SLOT(clear())
   );

   vbox.resize( 800, 400 );

   app.setMainWidget( &vbox );
   vbox.show();

   return app.exec();
}

